@@ -66,11 +66,18 @@ class create_window:
 
     def points_callback(self, points):
         # TODO: How to use numeric with dots (to input floats)
-        #self.points.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_FULL)
-        self.points.set_text(str(int(points)))
-        #self.points.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC)
+        self.points.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_FULL)
+        import math
+        if math.floor(points) != points:
+            self.points.set_text("%.1f" % points)
+        else:
+            self.points.set_text("%d" % points)
+        self.points.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC)
 
     def save(self, *args):
+        hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
+        while gtk.events_pending():
+            gtk.main_iteration()
         import time
         entry = storage.midgard.mgdschema.org_maemo_garage_maecalories_pointslog()
         entry.stock = self.template_button.get_active()
@@ -89,11 +96,15 @@ class create_window:
         try:
             entry.create()
         except:
+            hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
             note = hildon.Note('information', window, "Failed to create log entry, error: %s" . storage.midgard._connection.get_error_string())
             gtk.Dialog.run(note)
         print "Saved points log entry #%d with datetime %s" % (entry.id, repr(entry.time))
         # TODO: Just connect to signal in storage and be done with it
         storage.instance.update_caches()
+        hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
+        while gtk.events_pending():
+            gtk.main_iteration()
         self.window.destroy()
 
     def run(self):
@@ -200,7 +211,8 @@ class template_selector():
                 item.guid
             ))
 
-        # TODO: How to best show the points value too ?        
+        # TODO: How to best show the points value too ?
+        # TODO: make searchable
         self.selector = hildon.TouchSelector(text=True)
         self.selector.set_column_selection_mode(hildon.TOUCH_SELECTOR_SELECTION_MODE_SINGLE)
         self.selector.set_model(0, self.liststore)
@@ -223,8 +235,8 @@ class template_selector():
         self.dialog.set_selector(self.selector)
         ret = gtk.Dialog.run(self.dialog)
         self.active_row = self.selector.get_active(0)
-        print "run_dialog got ret %s" % repr(ret)
-        print "active row %d" % self.active_row
+        #print "run_dialog got ret %s" % repr(ret)
+        #print "active row %d" % self.active_row
         self.dialog.destroy()
         return ret
         
